import { IUserPool, IUserPoolClient } from 'aws-cdk-lib/aws-cognito';
import { Construct } from 'constructs';
import { IIdentityPool } from './identitypool';
/**
 * (experimental) Represents the concept of a User Pool Authentication Provider.
 *
 * You use user pool authentication providers to configure User Pools
 * and User Pool Clients for use with Identity Pools
 *
 * @experimental
 */
export interface IUserPoolAuthenticationProvider {
    /**
     * (experimental) The method called when a given User Pool Authentication Provider is added (for the first time) to an Identity Pool.
     *
     * @experimental
     */
    bind(scope: Construct, identityPool: IIdentityPool, options?: UserPoolAuthenticationProviderBindOptions): UserPoolAuthenticationProviderBindConfig;
}
/**
 * (experimental) Props for the User Pool Authentication Provider.
 *
 * @experimental
 */
export interface UserPoolAuthenticationProviderProps {
    /**
     * (experimental) The User Pool of the Associated Identity Providers.
     *
     * @experimental
     */
    readonly userPool: IUserPool;
    /**
     * (experimental) The User Pool Client for the provided User Pool.
     *
     * @default - A default user pool client will be added to User Pool
     * @experimental
     */
    readonly userPoolClient?: IUserPoolClient;
    /**
     * (experimental) Setting this to true turns off identity pool checks for this user pool to make sure the user has not been globally signed out or deleted before the identity pool provides an OIDC token or AWS credentials for the user.
     *
     * @default false
     * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cognito-identitypool-cognitoidentityprovider.html
     * @experimental
     */
    readonly disableServerSideTokenCheck?: boolean;
}
/**
 * (experimental) Represents UserPoolAuthenticationProvider Bind Options.
 *
 * @experimental
 */
export interface UserPoolAuthenticationProviderBindOptions {
}
/**
 * (experimental) Represents a UserPoolAuthenticationProvider Bind Configuration.
 *
 * @experimental
 */
export interface UserPoolAuthenticationProviderBindConfig {
    /**
     * (experimental) Client Id of the Associated User Pool Client.
     *
     * @experimental
     */
    readonly clientId: string;
    /**
     * (experimental) The identity providers associated with the UserPool.
     *
     * @experimental
     */
    readonly providerName: string;
    /**
     * (experimental) Whether to enable the identity pool's server side token check.
     *
     * @experimental
     */
    readonly serverSideTokenCheck: boolean;
}
/**
 * (experimental) Defines a User Pool Authentication Provider.
 *
 * @experimental
 */
export declare class UserPoolAuthenticationProvider implements IUserPoolAuthenticationProvider {
    /**
     * The User Pool of the Associated Identity Providers
     */
    private userPool;
    /**
     * The User Pool Client for the provided User Pool
     */
    private userPoolClient;
    /**
     * Whether to disable the pool's default server side token check
     */
    private disableServerSideTokenCheck;
    /**
     * @experimental
     */
    constructor(props: UserPoolAuthenticationProviderProps);
    /**
     * (experimental) The method called when a given User Pool Authentication Provider is added (for the first time) to an Identity Pool.
     *
     * @experimental
     */
    bind(scope: Construct, identityPool: IIdentityPool, _options?: UserPoolAuthenticationProviderBindOptions): UserPoolAuthenticationProviderBindConfig;
}
